@@ -18,6 +18,12 @@
 #ifndef ANDROID_DEFAULT
 # define ANDROID_DEFAULT 0
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
+#ifndef TARGET_DEFAULT_ASYNC_UNWIND_TABLES
+# define TARGET_DEFAULT_ASYNC_UNWIND_TABLES 1
+#endif
 #ifndef TARGET_DEFAULT_ISA_SPEC
 # define TARGET_DEFAULT_ISA_SPEC ISA_SPEC_CLASS_20191213
 #endif
